summaryrefslogtreecommitdiffstats
path: root/whineatnews.pl
diff options
context:
space:
mode:
authorMax Kanat-Alexander <mkanat@bugzilla.org>2010-07-06 02:42:57 +0200
committerMax Kanat-Alexander <mkanat@bugzilla.org>2010-07-06 02:42:57 +0200
commitba4585ae8a1c63a49e40461d2e2efc12bc75c58a (patch)
tree8dc9797b39e698089785eef1e6a2ca55e094934b /whineatnews.pl
parent4e7c28de087834ba8fca4350a01798c1f9732f23 (diff)
downloadbugzilla-ba4585ae8a1c63a49e40461d2e2efc12bc75c58a.tar.gz
bugzilla-ba4585ae8a1c63a49e40461d2e2efc12bc75c58a.tar.xz
Bug 486292: Change the default workflow to UNCONFIRMED, CONFIRMED,
IN_PROGRESS, RESOLVED, VERIFIED. r=LpSolit, a=mkanat
Diffstat (limited to 'whineatnews.pl')
-rwxr-xr-xwhineatnews.pl11
1 files changed, 7 insertions, 4 deletions
diff --git a/whineatnews.pl b/whineatnews.pl
index 7be485d29..19b0e44fc 100755
--- a/whineatnews.pl
+++ b/whineatnews.pl
@@ -25,8 +25,10 @@
# This is a script suitable for running once a day from a cron job. It
# looks at all the bugs, and sends whiny mail to anyone who has a bug
# assigned to them that has status NEW or REOPENED that has not been
# touched for more than the number of days specified in the whinedays param.
use strict;
use lib qw(. lib);
@@ -44,7 +46,7 @@ my $query = q{SELECT bug_id, short_desc, login_name
FROM bugs
INNER JOIN profiles
ON userid = assigned_to
- WHERE (bug_status = ? OR bug_status = ?)
+ WHERE bug_status IN (?,?,?)
AND disable_mail = 0
AND } . $dbh->sql_to_days('NOW()') . " - " .
$dbh->sql_to_days('delta_ts') . " > " .
@@ -54,7 +56,8 @@ my $query = q{SELECT bug_id, short_desc, login_name
my %bugs;
my %desc;
-my $slt_bugs = $dbh->selectall_arrayref($query, undef, 'NEW', 'REOPENED');
+my $slt_bugs = $dbh->selectall_arrayref($query, undef, 'CONFIRMED', 'NEW',
+ 'REOPENED');
foreach my $bug (@$slt_bugs) {
my ($id, $desc, $email) = @$bug;
@@ -25,8 +25,10 @@
# This is a script suitable for running once a day from a cron job. It
# looks at all the bugs, and sends whiny mail to anyone who has a bug
-# assigned to them that has status NEW or REOPENED that has not been
-# touched for more than the number of days specified in the whinedays param.
+# assigned to them that has status CONFIRMED, NEW, or REOPENED that has not
+# been touched for more than the number of days specified in the whinedays
+# param. (We have NEW and REOPENED in there to keep compatibility with old
+# Bugzillas.)
use strict;
use lib qw(. lib);